==> 1.0.0.zip: terraform-provider-dynamix/samples/cloudapi/bservice/resource_bservice_group/main.tf <==
/*
Пример использования
Работы с ресурсом basic service group
Ресурс позволяет:
1. Создавать группы
2. Редактировать группы
3. Удалять группы
*/

#Раскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    dynamix = {
      source  = "basistech.ru/tf/dynamix"
      version = "<VERSION>"
    }
  }
}
*/

provider "dynamix" {
  authenticator = "decs3o"
  #controller_url = <DECORT_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DECORT_SSO_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

resource "dynamix_bservice_group" "bsg" {
  #id basic service
  #обязательный параметр
  #тип - целое число
  service_id = 444444

  #название группы
  #обязательный параметр
  #тип - строка
  compgroup_name = "tf_group_rename"

  #id группы
  #необязательный параметр
  #тип - целое число
  #применяется при редактировании группы, либо при создании .tfstate - файла, если группа имеется в плафторме
  compgroup_id = 33333

  #кол-во вычислительных ресурсов
  #обязательный параметр
  #тип - целое число
  #используется так же для редактирования группы
  comp_count = 1

  #кол-во ядер на выч. ресурс
  #обязательный параметр
  #тип - целое число
  #используется так же для редактирования группы
  cpu = 2

  #кол-во оперативной памяти на выч. ресурс, в МБ
  #обязательный параметр
  #тип - целое число
  #используется так же для редактирования группы
  ram = 256

  #размер диска для выч. ресурса, в ГБ
  #обязательный параметр
  #тип - целое число
  #используется так же для редактирования группы
  disk = 11

  #id образа диска
  #обязательный параметр
  #тип - целое число
  image_id = 2222

  #драйвер
  #обязательный параметр
  #тип - строка
  driver = "kvm_x86"

  #id Storage endpoint provider 
  #необязательный параметр
  #тип - целое число
  sep_id = 3

  #Наименование SEPPool используется если установлен sepId, также может быть пустым
  #необязательный параметр
  #тип - строка
  sep_pool = "name"

  #тег группы
  #необязательный параметр
  #тип - строка
  #используется при создании и редактировании ресурса
  role           = "tf_test_changed"

  #id сетей extnet
  #необязательный параметр
  #тип - массив целых чисел
  #должен быть использован vins или extnets
  extnets = [1111, 2222]

  #id сетей vinses
  #необязательный параметр
  #тип - массив целых чисел
  #должен быть использован vins или extnets
  vinses        = [1111, 2222]

  #время таймуата перед стартом
  #необязательный параметр
  #тип - целое число
  #используется при создании ресурса
  timeout_start  = 0

  #Перечень аргументов для cloud-init создаваемым группам узлов Worker
  #необязательный параметр
  #тип - файл в формате YAML
  cloud_init = file("initconfig.tftpl")

  #id групп родителей
  #необязательный параметр
  #тип - массив целых чисел
  #используется при редактировании ресурса
  #parents = [2222]

  #принудительное обновление параметров выч. мощностей  (ram,disk,cpu) и имени группы
  #необязательный параметр
  #тип - булев
  #используется при редактировании ресурса
  #по-умолчанию - false
  #force_update   = true

  #старт/стоп вычислительных мощностей
  #необязательный параметр
  #тип - булев
  #используется при редактировании ресурса
  #по-умолчанию - false
  #start = false

  #принудительная остановка вычислительных мощностей
  #необязательный параметр
  #тип - булев
  #используется при редактировании и остановке группы
  #по-умолчанию - false
  #force_stop = false

  #удаление вычислительных мощностей
  #необязательный параметр
  #тип - массив целых чисел
  #используется при редактировании
  #remove_computes = [32287]

  #режим увеличения числа выч. мощностей
  #необязательный параметр
  #тип - строка
  #используется в связке с comp_count при редактировании группы
  #возможные варианты - RELATIVE и ABSOLUTE
  #по-умолчанию - "RELATIVE"
  #mode = "RELATIVE"

}

output "test" {
  value = dynamix_bservice_group.bsg
}

==> 1.2.1.zip: terraform-provider-dynamix/samples/cloudapi/bservice/resource_bservice_group/main.tf <==
/*
Пример использования
Работы с ресурсом basic service group
Ресурс позволяет:
1. Создавать группы
2. Редактировать группы
3. Удалять группы
*/

#Раскомментируйте этот код,
#и внесите необходимые правки в версию и путь,
#чтобы работать с установленным вручную (не через hashicorp provider registry) провайдером
/*
terraform {
  required_providers {
    dynamix = {
      source  = "basistech.ru/tf/dynamix"
      version = "<VERSION>"
    }
  }
}
*/

provider "dynamix" {
  authenticator = "decs3o"
  #controller_url = <DYNAMIX_CONTROLLER_URL>
  controller_url = "https://ds1.digitalenergy.online"
  #oauth2_url = <DYNAMIX_OAUTH2_URL>
  oauth2_url           = "https://sso.digitalenergy.online"
  allow_unverified_ssl = true
}

resource "dynamix_bservice_group" "bsg" {
  #id basic service
  #обязательный параметр
  #тип - целое число
  service_id = 444444

  #название группы
  #обязательный параметр
  #тип - строка
  compgroup_name = "tf_group_rename"

  #id группы
  #необязательный параметр
  #тип - целое число
  #применяется при редактировании группы, либо при создании .tfstate - файла, если группа имеется в плафторме
  compgroup_id = 33333

  #кол-во вычислительных ресурсов
  #обязательный параметр
  #тип - целое число
  #используется так же для редактирования группы
  comp_count = 1

  #кол-во ядер на выч. ресурс
  #обязательный параметр
  #тип - целое число
  #используется так же для редактирования группы
  cpu = 2

  #кол-во оперативной памяти на выч. ресурс, в МБ
  #обязательный параметр
  #тип - целое число
  #используется так же для редактирования группы
  ram = 256

  #размер диска для выч. ресурса, в ГБ
  #обязательный параметр
  #тип - целое число
  #используется так же для редактирования группы
  disk = 11

  #id образа диска
  #обязательный параметр
  #тип - целое число
  image_id = 2222

  #драйвер
  #обязательный параметр
  #тип - строка
  driver = "kvm_x86"

  #id Storage endpoint provider 
  #необязательный параметр
  #тип - целое число
  sep_id = 3

  #Наименование SEPPool используется если установлен sepId, также может быть пустым
  #необязательный параметр
  #тип - строка
  sep_pool = "name"

  #тег группы
  #необязательный параметр
  #тип - строка
  #используется при создании и редактировании ресурса
  role           = "tf_test_changed"

  #id сетей extnet
  #необязательный параметр
  #тип - массив целых чисел
  #должен быть использован vins или extnets
  extnets = [1111, 2222]

  #id сетей vinses
  #необязательный параметр
  #тип - массив целых чисел
  #должен быть использован vins или extnets
  vinses        = [1111, 2222]

  #время таймуата перед стартом
  #необязательный параметр
  #тип - целое число
  #используется при создании ресурса
  timeout_start  = 0

  #Перечень аргументов для cloud-init создаваемым группам узлов Worker
  #необязательный параметр
  #тип - файл в формате YAML
  cloud_init = file("initconfig.tftpl")

  #id групп родителей
  #необязательный параметр
  #тип - массив целых чисел
  #используется при редактировании ресурса
  #parents = [2222]

  #принудительное обновление параметров выч. мощностей  (ram,disk,cpu) и имени группы
  #необязательный параметр
  #тип - булев
  #используется при редактировании ресурса
  #по-умолчанию - false
  #force_update   = true

  #старт/стоп вычислительных мощностей
  #необязательный параметр
  #тип - булев
  #используется при редактировании ресурса
  #по-умолчанию - false
  #start = false

  #принудительная остановка вычислительных мощностей
  #необязательный параметр
  #тип - булев
  #используется при редактировании и остановке группы
  #по-умолчанию - false
  #force_stop = false

  #удаление вычислительных мощностей
  #необязательный параметр
  #тип - массив целых чисел
  #используется при редактировании
  #remove_computes = [32287]

  #режим увеличения числа выч. мощностей
  #необязательный параметр
  #тип - строка
  #используется в связке с comp_count при редактировании группы
  #возможные варианты - RELATIVE и ABSOLUTE
  #по-умолчанию - "RELATIVE"
  #mode = "RELATIVE"

}

output "test" {
  value = dynamix_bservice_group.bsg
}
